Package: neotoma2
Title: Working with the Neotoma Paleoecology Database
Date: 2026-04-23
Version: 1.0.12
Authors@R: 
    c(person(given = "Dominguez Vidana",
             family = "Socorro",
             role = c("aut", "cre"),
             email = "dominguezvid@wisc.edu",
             comment = c(ORCID="0000-0002-7926-4935")),
      person(given = "Simon",
             family = "Goring",
             role = c("aut"),
             email = "goring@wisc.edu",
             comment = c(ORCID="0000-0002-2700-4605")))
URL: https://github.com/NeotomaDB/neotoma2
BugReports: https://github.com/NeotomaDB/neotoma2/issues
Description: Access and manipulation of data using the Neotoma Paleoecology Database.
        <https://api.neotomadb.org/api-docs/>.
        Examples in functions that require API access are not executed during CRAN checks.
        Vignettes do not execute as to avoid API calls during CRAN checks.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat, knitr, pkgdown, rmarkdown, ggplot2, Bchron, covr,
Imports: rlang, magrittr, sf, digest, geojsonsf, purrr, httr, jsonlite,
        methods, dplyr, leaflet, assertthat, stringr, progress, uuid,
        utils, tidyr
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-23 19:21:41 UTC; sedv8808
Author: Dominguez Vidana Socorro [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7926-4935>),
  Simon Goring [aut] (ORCID: <https://orcid.org/0000-0002-2700-4605>)
Maintainer: Dominguez Vidana Socorro <dominguezvid@wisc.edu>
Repository: CRAN
Date/Publication: 2026-04-23 19:50:03 UTC
Built: R 4.5.2; ; 2026-04-24 13:28:47 UTC; unix
