# Generated by roxygen2: do not edit by hand

S3method(check_contacts,contacts)
S3method(clean,collunits)
S3method(clean,datasets)
S3method(clean,sites)
S3method(filter,NULL)
S3method(filter,data.frame)
S3method(filter,sites)
S3method(get_contacts,default)
S3method(get_contacts,numeric)
S3method(get_datasets,NULL)
S3method(get_datasets,default)
S3method(get_datasets,numeric)
S3method(get_datasets,site)
S3method(get_datasets,sites)
S3method(get_downloads,NULL)
S3method(get_downloads,numeric)
S3method(get_downloads,sites)
S3method(get_publications,default)
S3method(get_publications,numeric)
S3method(get_publications,publication)
S3method(get_publications,publications)
S3method(get_publications,sites)
S3method(get_sites,NULL)
S3method(get_sites,default)
S3method(get_sites,numeric)
S3method(get_speleothems,numeric)
S3method(get_speleothems,sites)
S3method(get_taxa,default)
S3method(get_taxa,numeric)
S3method(get_taxon,default)
S3method(get_taxon,numeric)
S3method(getids,collunit)
S3method(getids,collunits)
S3method(getids,sites)
S3method(neotoma2::getids,site)
export("%>%")
export(check_contacts)
export(chroncontrols)
export(chronologies)
export(cite_data)
export(clean)
export(collunits)
export(coordinates)
export(datasets)
export(doi)
export(filter)
export(get_contacts)
export(get_datasets)
export(get_documentation)
export(get_downloads)
export(get_manual)
export(get_publications)
export(get_sites)
export(get_speleothems)
export(get_stats)
export(get_table)
export(get_taxa)
export(get_taxon)
export(getids)
export(getids.sites)
export(pingNeotoma)
export(plotLeaflet)
export(samples)
export(set_chronology)
export(set_collunit)
export(set_contact)
export(set_dataset)
export(set_default)
export(set_publication)
export(set_sample)
export(set_server)
export(set_site)
export(set_speleothem)
export(speleothemdetails)
export(speleothems)
export(taxa)
export(toWide)
exportClasses(author)
exportClasses(authors)
exportClasses(chronologies)
exportClasses(chronology)
exportClasses(collunit)
exportClasses(collunits)
exportClasses(contact)
exportClasses(contacts)
exportClasses(dataset)
exportClasses(datasets)
exportClasses(publication)
exportClasses(publications)
exportClasses(repositories)
exportClasses(repository)
exportClasses(sample)
exportClasses(samples)
exportClasses(site)
exportClasses(sites)
exportClasses(specimen)
exportClasses(specimens)
exportClasses(speleothem)
exportClasses(speleothems)
exportClasses(taxa)
exportClasses(taxon)
exportMethods("$")
exportMethods("$<-")
exportMethods("[")
exportMethods("[<-")
exportMethods("[[")
exportMethods("[[<-")
exportMethods(add_chronology)
exportMethods(as.data.frame)
exportMethods(c)
exportMethods(chroncontrols)
exportMethods(chronologies)
exportMethods(cite_data)
exportMethods(collunits)
exportMethods(coordinates)
exportMethods(datasets)
exportMethods(doi)
exportMethods(length)
exportMethods(names)
exportMethods(plot)
exportMethods(plotLeaflet)
exportMethods(samples)
exportMethods(set_default)
exportMethods(speleothemdetails)
exportMethods(speleothems)
exportMethods(summary)
exportMethods(taxa)
importFrom(assertthat,assert_that)
importFrom(digest,digest)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,coalesce)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,group_by_at)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,rename)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(geojsonsf,geojson_sf)
importFrom(geojsonsf,sf_geojson)
importFrom(geojsonsf,sfc_geojson)
importFrom(httr,GET)
importFrom(httr,HEAD)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,modify_url)
importFrom(httr,stop_for_status)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(leaflet,addCircleMarkers)
importFrom(leaflet,addTiles)
importFrom(leaflet,leaflet)
importFrom(leaflet,markerClusterOptions)
importFrom(leaflet,markerOptions)
importFrom(magrittr,"%>%")
importFrom(methods,"slot<-")
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,slot)
importFrom(methods,slotNames)
importFrom(progress,progress_bar)
importFrom(purrr,flatten)
importFrom(purrr,imap)
importFrom(purrr,map)
importFrom(purrr,map_df)
importFrom(purrr,map_lgl)
importFrom(purrr,pluck)
importFrom(purrr,reduce)
importFrom(rlang,.data)
importFrom(rlang,is_interactive)
importFrom(sf,st_as_sf)
importFrom(sf,st_as_sfc)
importFrom(sf,st_bbox)
importFrom(sf,st_coordinates)
importFrom(sf,st_crs)
importFrom(sf,st_read)
importFrom(sf,st_sfc)
importFrom(stats,na.omit)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_match)
importFrom(stringr,str_match_all)
importFrom(tidyr,pivot_wider)
importFrom(utils,browseURL)
importFrom(uuid,UUIDgenerate)
importMethodsFrom(methods,show)
