% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_params.R
\name{get_params}
\alias{get_params}
\title{get_params}
\usage{
get_params(obj)
}
\description{
get_params
}
\author{
Socorro Dominguez \email{dominguezvid@wisc.edu}
}
\keyword{internal}
